@@ -498,8 +498,7 @@ class PyMarkdownApi:
             property_value (bool): `True` or `False` boolean value to set the property to.
 
         Raises:
-            PyMarkdownApiArgumentException: If `property_name` is empty or if `property_value`
-            is not a `bool` value.
+            PyMarkdownApiArgumentException: If `property_name` is empty or if `property_value` is not a `bool` value.
 
         Returns:
             An instance of `PyMarkdownApi` to allow for function chaining.
@@ -532,8 +531,7 @@ class PyMarkdownApi:
             property_value (int): Integer value to set the property to.
 
         Raises:
-            PyMarkdownApiArgumentException: If `property_name` is empty or if
-            `property_value` is not an `int` value.
+            PyMarkdownApiArgumentException: If `property_name` is empty or if `property_value` is not an `int` value.
 
         Returns:
             An instance of `PyMarkdownApi` to allow for function chaining.
@@ -566,8 +564,7 @@ class PyMarkdownApi:
             property_value (str): String value to set the property to.
 
         Raises:
-            PyMarkdownApiArgumentException: If `property_name` is empty or if
-            `property_value` is not an `str` value.
+            PyMarkdownApiArgumentException: If `property_name` is empty or if `property_value` is not an `str` value.
 
         Returns:
             An instance of `PyMarkdownApi` to allow for function chaining.
@@ -998,7 +995,7 @@ class PyMarkdownScanFailure:
         column_number (int): Column number of the triggered rule failure.
         rule_id (str): ID of the rule that was triggered.
         rule_name (str): Name(s) of the rule that was triggered.
-        rule_description (str) Longer description of the rule that was triggered.
+        rule_description (str): Longer description of the rule that was triggered.
         extra_error_information (Optional[str]): String providing more information on why the rule was triggered.
     """
 
@@ -1043,7 +1040,7 @@ class PyMarkdownPragmaError:
     - specific information on why PyMarkdown generated the pragma error
 
     More information on Pragmas and
-    their use are available [here](./user-guide.md#pragma-extension).
+    their use are available [here](../user-guide.md#pragma-extension).
 
     Attributes:
         file_path (str): Path to the file that contains the improperly constructed pragma.
